tsseg.algorithms.binseg package
===============================

Recursively applies a single-change test and splits at the most significant change
point.

| **Type:** change point detection
| **Supervision:** semi-supervised or unsupervised
| **Scope:** univariate and multivariate
| **Complexity:** O(n log n)

**Implementation:** Vendored from ruptures v1.1.8. BSD 2-Clause.

**Reference:** Truong, Oudre & Vayatis (2020), Signal Processing.

Submodules
----------

tsseg.algorithms.binseg.detector module
---------------------------------------

.. automodule:: tsseg.algorithms.binseg.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.binseg
   :members:
   :show-inheritance:
   :undoc-members:
